Module: ExcADG::Payload::Example

Defined in:
lib/excadg/payload/example.rb

Overview

payload examples to demonstrate framework capabilities most of the payloads in the file are used in tests

Defined Under Namespace

Classes: Condition, Echo, Faulty, Loop, Multiplier, Receiver, Sleepy